==> sumus-6.3.3-sources.jar: io/intino/sumus/graph/Checker.java <==
package io.intino.sumus.graph;

import io.intino.sumus.graph.*;
import io.intino.sumus.graph.Record;


public class Checker extends io.intino.tara.magritte.Layer implements io.intino.tara.magritte.tags.Terminal {
	protected io.intino.tara.magritte.Concept record;
	protected java.util.List<io.intino.sumus.graph.Checker.Rule> ruleList = new java.util.ArrayList<>();

	public Checker(io.intino.tara.magritte.Node node) {
		super(node);
	}

	public io.intino.tara.magritte.Concept record() {
		return this.record;
	}

	public Checker record(io.intino.tara.magritte.Concept value) {
		this.record = value;
		return (Checker) this;
	}

	public java.util.List<io.intino.sumus.graph.Checker.Rule> ruleList() {
		return java.util.Collections.unmodifiableList(ruleList);
	}

	public io.intino.sumus.graph.Checker.Rule rule(int index) {
		return ruleList.get(index);
	}

	public java.util.List<io.intino.sumus.graph.Checker.Rule> ruleList(java.util.function.Predicate<io.intino.sumus.graph.Checker.Rule> predicate) {
		return ruleList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}



	protected java.util.List<io.intino.tara.magritte.Node> componentList$() {
		java.util.Set<io.intino.tara.magritte.Node> components = new java.util.LinkedHashSet<>(super.componentList$());
		new java.util.ArrayList<>(ruleList).forEach(c -> components.add(c.core$()));
		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
		map.put("record", this.record != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.record)) : java.util.Collections.emptyList());
		return map;
	}

	@Override
	protected void addNode$(io.intino.tara.magritte.Node node) {
		super.addNode$(node);
		if (node.is("Checker$Rule")) this.ruleList.add(node.as(io.intino.sumus.graph.Checker.Rule.class));
	}

	@Override
    protected void removeNode$(io.intino.tara.magritte.Node node) {
        super.removeNode$(node);
        if (node.is("Checker$Rule")) this.ruleList.remove(node.as(io.intino.sumus.graph.Checker.Rule.class));
    }

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
		if (name.equalsIgnoreCase("record")) this.record = io.intino.tara.magritte.loaders.ConceptLoader.load(values, this).get(0);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
		if (name.equalsIgnoreCase("record")) this.record = (io.intino.tara.magritte.Concept) values.get(0);
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create  {
		protected final java.lang.String name;

		public Create(java.lang.String name) {
			this.name = name;
		}

		public io.intino.sumus.graph.Checker.Rule rule(io.intino.sumus.graph.functions.CheckRecord check, io.intino.tara.magritte.Expression<java.lang.String> message) {
		    io.intino.sumus.graph.Checker.Rule newElement = core$().graph().concept(io.intino.sumus.graph.Checker.Rule.class).createNode(name, core$()).as(io.intino.sumus.graph.Checker.Rule.class);
			newElement.core$().set(newElement, "check", java.util.Collections.singletonList(check));
			newElement.core$().set(newElement, "message", java.util.Collections.singletonList(message));
		    return newElement;
		}

	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear  {
		public void rule(java.util.function.Predicate<io.intino.sumus.graph.Checker.Rule> filter) {
			new java.util.ArrayList<>(ruleList()).stream().filter(filter).forEach(io.intino.tara.magritte.Layer::delete$);
		}
	}

	public static class Rule extends io.intino.tara.magritte.Layer implements io.intino.tara.magritte.tags.Terminal {
		protected io.intino.sumus.graph.functions.CheckRecord check;
		protected io.intino.tara.magritte.Expression<java.lang.String> message;

		public Rule(io.intino.tara.magritte.Node node) {
			super(node);
		}

		public boolean check(Record record) {
			return check.check(record);
		}

		public java.lang.String message() {
			return message.value();
		}

		public Rule check(io.intino.sumus.graph.functions.CheckRecord value) {
			this.check = io.intino.tara.magritte.loaders.FunctionLoader.load(check, this, io.intino.sumus.graph.functions.CheckRecord.class);
			return (Rule) this;
		}

		public Rule message(io.intino.tara.magritte.Expression<java.lang.String> value) {
			this.message = io.intino.tara.magritte.loaders.FunctionLoader.load(value, this, io.intino.tara.magritte.Expression.class);
			return (Rule) this;
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
			map.put("check", this.check != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.check)) : java.util.Collections.emptyList());
			map.put("message", new java.util.ArrayList(java.util.Collections.singletonList(this.message)));
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("check")) this.check = io.intino.tara.magritte.loaders.FunctionLoader.load(values, this, io.intino.sumus.graph.functions.CheckRecord.class).get(0);
			else if (name.equalsIgnoreCase("message")) this.message = io.intino.tara.magritte.loaders.FunctionLoader.load(values, this, io.intino.tara.magritte.Expression.class).get(0);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("check")) this.check = io.intino.tara.magritte.loaders.FunctionLoader.load(values.get(0), this, io.intino.sumus.graph.functions.CheckRecord.class);
			else if (name.equalsIgnoreCase("message")) this.message = io.intino.tara.magritte.loaders.FunctionLoader.load(values.get(0), this, io.intino.tara.magritte.Expression.class);
		}


		public io.intino.sumus.graph.SumusGraph graph() {
			return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
		}
	}


	public io.intino.sumus.graph.SumusGraph graph() {
		return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
	}
}

==> sumus-7.2.1-sources.jar: io/intino/sumus/graph/Checker.java <==
package io.intino.sumus.graph;

import io.intino.sumus.graph.*;
import io.intino.sumus.graph.Record;


public class Checker extends io.intino.tara.magritte.Layer implements io.intino.tara.magritte.tags.Terminal {
	protected io.intino.tara.magritte.Concept record;
	protected java.util.List<io.intino.sumus.graph.Checker.Rule> ruleList = new java.util.ArrayList<>();

	public Checker(io.intino.tara.magritte.Node node) {
		super(node);
	}

	public io.intino.tara.magritte.Concept record() {
		return this.record;
	}

	public Checker record(io.intino.tara.magritte.Concept value) {
		this.record = value;
		return (Checker) this;
	}

	public java.util.List<io.intino.sumus.graph.Checker.Rule> ruleList() {
		return java.util.Collections.unmodifiableList(ruleList);
	}

	public io.intino.sumus.graph.Checker.Rule rule(int index) {
		return ruleList.get(index);
	}

	public java.util.List<io.intino.sumus.graph.Checker.Rule> ruleList(java.util.function.Predicate<io.intino.sumus.graph.Checker.Rule> predicate) {
		return ruleList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}



	protected java.util.List<io.intino.tara.magritte.Node> componentList$() {
		java.util.Set<io.intino.tara.magritte.Node> components = new java.util.LinkedHashSet<>(super.componentList$());
		new java.util.ArrayList<>(ruleList).forEach(c -> components.add(c.core$()));
		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
		map.put("record", this.record != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.record)) : java.util.Collections.emptyList());
		return map;
	}

	@Override
	protected void addNode$(io.intino.tara.magritte.Node node) {
		super.addNode$(node);
		if (node.is("Checker$Rule")) this.ruleList.add(node.as(io.intino.sumus.graph.Checker.Rule.class));
	}

	@Override
    protected void removeNode$(io.intino.tara.magritte.Node node) {
        super.removeNode$(node);
        if (node.is("Checker$Rule")) this.ruleList.remove(node.as(io.intino.sumus.graph.Checker.Rule.class));
    }

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
		if (name.equalsIgnoreCase("record")) this.record = io.intino.tara.magritte.loaders.ConceptLoader.load(values, this).get(0);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
		if (name.equalsIgnoreCase("record")) this.record = (io.intino.tara.magritte.Concept) values.get(0);
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create  {
		protected final java.lang.String name;

		public Create(java.lang.String name) {
			this.name = name;
		}

		public io.intino.sumus.graph.Checker.Rule rule(io.intino.sumus.graph.functions.CheckRecord check, io.intino.tara.magritte.Expression<java.lang.String> message) {
		    io.intino.sumus.graph.Checker.Rule newElement = core$().graph().concept(io.intino.sumus.graph.Checker.Rule.class).createNode(this.name, core$()).as(io.intino.sumus.graph.Checker.Rule.class);
			newElement.core$().set(newElement, "check", java.util.Collections.singletonList(check));
			newElement.core$().set(newElement, "message", java.util.Collections.singletonList(message));
		    return newElement;
		}

	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear  {
		public void rule(java.util.function.Predicate<io.intino.sumus.graph.Checker.Rule> filter) {
			new java.util.ArrayList<>(ruleList()).stream().filter(filter).forEach(io.intino.tara.magritte.Layer::delete$);
		}
	}

	public static class Rule extends io.intino.tara.magritte.Layer implements io.intino.tara.magritte.tags.Terminal {
		protected io.intino.sumus.graph.functions.CheckRecord check;
		protected io.intino.tara.magritte.Expression<java.lang.String> message;

		public Rule(io.intino.tara.magritte.Node node) {
			super(node);
		}

		public boolean check(Record record) {
			return check.check(record);
		}

		public java.lang.String message() {
			return message.value();
		}

		public Rule check(io.intino.sumus.graph.functions.CheckRecord value) {
			this.check = io.intino.tara.magritte.loaders.FunctionLoader.load(check, this, io.intino.sumus.graph.functions.CheckRecord.class);
			return (Rule) this;
		}

		public Rule message(io.intino.tara.magritte.Expression<java.lang.String> value) {
			this.message = io.intino.tara.magritte.loaders.FunctionLoader.load(value, this, io.intino.tara.magritte.Expression.class);
			return (Rule) this;
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
			map.put("check", this.check != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.check)) : java.util.Collections.emptyList());
			map.put("message", new java.util.ArrayList(java.util.Collections.singletonList(this.message)));
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("check")) this.check = io.intino.tara.magritte.loaders.FunctionLoader.load(values, this, io.intino.sumus.graph.functions.CheckRecord.class).get(0);
			else if (name.equalsIgnoreCase("message")) this.message = io.intino.tara.magritte.loaders.FunctionLoader.load(values, this, io.intino.tara.magritte.Expression.class).get(0);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("check")) this.check = io.intino.tara.magritte.loaders.FunctionLoader.load(values.get(0), this, io.intino.sumus.graph.functions.CheckRecord.class);
			else if (name.equalsIgnoreCase("message")) this.message = io.intino.tara.magritte.loaders.FunctionLoader.load(values.get(0), this, io.intino.tara.magritte.Expression.class);
		}


		public io.intino.sumus.graph.SumusGraph graph() {
			return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
		}
	}


	public io.intino.sumus.graph.SumusGraph graph() {
		return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
	}
}
